@@ -2,14 +2,15 @@ import urllib
 from datetime import datetime
 from time import sleep
 from meilisearch._httprequests import HttpRequests
+from meilisearch.errors import MeiliSearchTimeoutError
 
 # pylint: disable=too-many-public-methods
 class Index():
     """
     Indexes routes wrapper.
 
-    Index class gives access to all indexes routes and child routes (herited).
-    https://docs.meilisearch.com/references/indexes.html
+    Index class gives access to all indexes routes and child routes (inherited).
+    https://docs.meilisearch.com/reference/api/indexes.html
     """
 
     config = None
@@ -41,7 +42,7 @@ class Index():
         MeiliSearchApiError
             An error containing details about why MeiliSearch can't process your request. MeiliSearch error codes are described here: https://docs.meilisearch.com/errors/#meilisearch-errors
         """
-        return self.http.delete('{}/{}'.format(self.config.paths.index, self.uid))
+        return self.http.delete(f'{self.config.paths.index}/{self.uid}')
 
     def update(self, **body):
         """Update the index primary-key.
@@ -54,8 +55,8 @@ class Index():
 
         Returns
         -------
-        index: dict
-            Dictionary containing index information.
+        index : Index
+            An instance of Index
 
         Raises
         ------
@@ -66,7 +67,7 @@ class Index():
         primary_key = body.get('primaryKey', None)
         if primary_key is not None:
             payload['primaryKey'] = primary_key
-        response = self.http.put('{}/{}'.format(self.config.paths.index, self.uid), payload)
+        response = self.http.put(f'{self.config.paths.index}/{self.uid}', payload)
         self.primary_key = response['primaryKey']
         return self
 
@@ -75,15 +76,15 @@ class Index():
 
         Returns
         -------
-        index: dict
-            Dictionary containing the index information.
+        index : Index
+            An instance of Index
 
         Raises
         ------
         MeiliSearchApiError
             An error containing details about why MeiliSearch can't process your request. MeiliSearch error codes are described here: https://docs.meilisearch.com/errors/#meilisearch-errors
         """
-        index_dict = self.http.get('{}/{}'.format(self.config.paths.index, self.uid))
+        index_dict = self.http.get(f'{self.config.paths.index}/{self.uid}')
         self.primary_key = index_dict['primaryKey']
         return self
 
@@ -143,11 +144,7 @@ class Index():
             An error containing details about why MeiliSearch can't process your request. MeiliSearch error codes are described here: https://docs.meilisearch.com/errors/#meilisearch-errors
         """
         return self.http.get(
-            '{}/{}/{}'.format(
-                self.config.paths.index,
-                self.uid,
-                self.config.paths.update
-            )
+            f'{self.config.paths.index}/{self.uid}/{self.config.paths.update}'
         )
 
     def get_update_status(self, update_id):
@@ -169,12 +166,7 @@ class Index():
             An error containing details about why MeiliSearch can't process your request. MeiliSearch error codes are described here: https://docs.meilisearch.com/errors/#meilisearch-errors
         """
         return self.http.get(
-            '{}/{}/{}/{}'.format(
-                self.config.paths.index,
-                self.uid,
-                self.config.paths.update,
-                update_id
-            )
+            f'{self.config.paths.index}/{self.uid}/{self.config.paths.update}/{update_id}'
         )
 
     def wait_for_pending_update(self, update_id, timeout_in_ms=5000, interval_in_ms=50):
@@ -185,7 +177,7 @@ class Index():
         update_id: int
             identifier of the update to retrieve
         timeout_in_ms (optional): int
-            time the method should wait before rising a TimeoutError
+            time the method should wait before raising a MeiliSearchTimeoutError
         interval_in_ms (optional): int
             time interval the method should wait (sleep) between requests
 
@@ -196,7 +188,7 @@ class Index():
 
         Raises
         ------
-        MeiliSearchApiError
+        MeiliSearchTimeoutError
             An error containing details about why MeiliSearch can't process your request. MeiliSearch error codes are described here: https://docs.meilisearch.com/errors/#meilisearch-errors
         """
         start_time = datetime.now()
@@ -208,13 +200,13 @@ class Index():
             sleep(interval_in_ms / 1000)
             time_delta = datetime.now() - start_time
             elapsed_time = time_delta.seconds * 1000 + time_delta.microseconds / 1000
-        raise TimeoutError
+        raise MeiliSearchTimeoutError(f'timeout of ${timeout_in_ms}ms has exceeded on process ${update_id} when waiting for pending update to resolve.')
 
     def get_stats(self):
         """Get stats of the index.
 
         Get information about the number of documents, field frequencies, ...
-        https://docs.meilisearch.com/references/stats.html
+        https://docs.meilisearch.com/reference/api/stats.html
 
         Returns
         -------
@@ -227,11 +219,7 @@ class Index():
             An error containing details about why MeiliSearch can't process your request. MeiliSearch error codes are described here: https://docs.meilisearch.com/errors/#meilisearch-errors
         """
         return self.http.get(
-            '{}/{}/{}'.format(
-                self.config.paths.index,
-                self.uid,
-                self.config.paths.stat,
-            )
+            f'{self.config.paths.index}/{self.uid}/{self.config.paths.stat}'
         )
 
     def search(self, query, opt_params=None):
@@ -243,7 +231,7 @@ class Index():
             String containing the searched word(s)
         opt_params (optional): dict
             Dictionary containing optional query parameters
-            https://docs.meilisearch.com/references/search.html#search-in-an-index
+            https://docs.meilisearch.com/reference/api/search.html#search-in-an-index
 
         Returns
         -------
@@ -262,10 +250,7 @@ class Index():
             **opt_params
         }
         return self.http.post(
-            '{}/{}/{}'.format(
-                self.config.paths.index,
-                self.uid,
-                self.config.paths.search),
+            f'{self.config.paths.index}/{self.uid}/{self.config.paths.search}',
             body=body
         )
 
@@ -288,12 +273,7 @@ class Index():
             An error containing details about why MeiliSearch can't process your request. MeiliSearch error codes are described here: https://docs.meilisearch.com/errors/#meilisearch-errors
         """
         return self.http.get(
-            '{}/{}/{}/{}'.format(
-                self.config.paths.index,
-                self.uid,
-                self.config.paths.document,
-                document_id
-            )
+            f'{self.config.paths.index}/{self.uid}/{self.config.paths.document}/{document_id}'
         )
 
     def get_documents(self, parameters=None):
@@ -302,7 +282,7 @@ class Index():
         Parameters
         ----------
         parameters (optional): dict
-            parameters accepted by the get documents route: https://docs.meilisearch.com/references/documents.html#get-all-documents
+            parameters accepted by the get documents route: https://docs.meilisearch.com/reference/api/documents.html#get-all-documents
 
         Returns
         -------
@@ -318,12 +298,8 @@ class Index():
             parameters = {}
 
         return self.http.get(
-            '{}/{}/{}?{}'.format(
-                self.config.paths.index,
-                self.uid,
-                self.config.paths.document,
-                urllib.parse.urlencode(parameters))
-            )
+            f'{self.config.paths.index}/{self.uid}/{self.config.paths.document}?{urllib.parse.urlencode(parameters)}'
+        )
 
     def add_documents(self, documents, primary_key=None):
         """Add documents to the index.
@@ -339,7 +315,7 @@ class Index():
         -------
         update: dict
             Dictionary containing an update id to track the action:
-            https://docs.meilisearch.com/references/updates.html#get-an-update-status
+            https://docs.meilisearch.com/reference/api/updates.html#get-an-update-status
 
         Raises
         ------
@@ -347,18 +323,10 @@ class Index():
             An error containing details about why MeiliSearch can't process your request. MeiliSearch error codes are described here: https://docs.meilisearch.com/errors/#meilisearch-errors
         """
         if primary_key is None:
-            url = '{}/{}/{}'.format(
-                self.config.paths.index,
-                self.uid,
-                self.config.paths.document
-            )
+            url = f'{self.config.paths.index}/{self.uid}/{self.config.paths.document}'
         else:
-            url = '{}/{}/{}?{}'.format(
-                self.config.paths.index,
-                self.uid,
-                self.config.paths.document,
-                urllib.parse.urlencode({'primaryKey': primary_key})
-            )
+            primary_key = urllib.parse.urlencode({'primaryKey': primary_key})
+            url = f'{self.config.paths.index}/{self.uid}/{self.config.paths.document}?{primary_key}'
         return self.http.post(url, documents)
 
     def update_documents(self, documents, primary_key=None):
@@ -375,7 +343,7 @@ class Index():
         -------
         update: dict
             Dictionary containing an update id to track the action:
-            https://docs.meilisearch.com/references/updates.html#get-an-update-status
+            https://docs.meilisearch.com/reference/api/updates.html#get-an-update-status
 
         Raises
         ------
@@ -383,18 +351,10 @@ class Index():
             An error containing details about why MeiliSearch can't process your request. MeiliSearch error codes are described here: https://docs.meilisearch.com/errors/#meilisearch-errors
         """
         if primary_key is None:
-            url = '{}/{}/{}'.format(
-                self.config.paths.index,
-                self.uid,
-                self.config.paths.document
-            )
+            url = f'{self.config.paths.index}/{self.uid}/{self.config.paths.document}'
         else:
-            url = '{}/{}/{}?{}'.format(
-                self.config.paths.index,
-                self.uid,
-                self.config.paths.document,
-                urllib.parse.urlencode({'primaryKey': primary_key})
-            )
+            primary_key = urllib.parse.urlencode({'primaryKey': primary_key})
+            url = f'{self.config.paths.index}/{self.uid}/{self.config.paths.document}?{primary_key}'
         return self.http.put(url, documents)
 
 
@@ -410,7 +370,7 @@ class Index():
         -------
         update: dict
             Dictionary containing an update id to track the action:
-            https://docs.meilisearch.com/references/updates.html#get-an-update-status
+            https://docs.meilisearch.com/reference/api/updates.html#get-an-update-status
 
         Raises
         ------
@@ -418,12 +378,7 @@ class Index():
             An error containing details about why MeiliSearch can't process your request. MeiliSearch error codes are described here: https://docs.meilisearch.com/errors/#meilisearch-errors
         """
         return self.http.delete(
-            '{}/{}/{}/{}'.format(
-                self.config.paths.index,
-                self.uid,
-                self.config.paths.document,
-                document_id
-            )
+            f'{self.config.paths.index}/{self.uid}/{self.config.paths.document}/{document_id}'
         )
 
     def delete_documents(self, ids):
@@ -438,7 +393,7 @@ class Index():
         -------
         update: dict
             Dictionary containing an update id to track the action:
-            https://docs.meilisearch.com/references/updates.html#get-an-update-status
+            https://docs.meilisearch.com/reference/api/updates.html#get-an-update-status
 
         Raises
         ------
@@ -446,11 +401,7 @@ class Index():
             An error containing details about why MeiliSearch can't process your request. MeiliSearch error codes are described here: https://docs.meilisearch.com/errors/#meilisearch-errors
         """
         return self.http.post(
-            '{}/{}/{}/delete-batch'.format(
-                self.config.paths.index,
-                self.uid,
-                self.config.paths.document
-            ),
+            f'{self.config.paths.index}/{self.uid}/{self.config.paths.document}/delete-batch',
             ids
         )
 
@@ -461,7 +412,7 @@ class Index():
         -------
         update: dict
             Dictionary containing an update id to track the action:
-            https://docs.meilisearch.com/references/updates.html#get-an-update-status
+            https://docs.meilisearch.com/reference/api/updates.html#get-an-update-status
 
         Raises
         ------
@@ -469,11 +420,7 @@ class Index():
             An error containing details about why MeiliSearch can't process your request. MeiliSearch error codes are described here: https://docs.meilisearch.com/errors/#meilisearch-errors
         """
         return self.http.delete(
-            '{}/{}/{}'.format(
-                self.config.paths.index,
-                self.uid,
-                self.config.paths.document
-            )
+            f'{self.config.paths.index}/{self.uid}/{self.config.paths.document}'
         )
 
 
@@ -482,7 +429,7 @@ class Index():
     def get_settings(self):
         """Get settings of the index.
 
-        https://docs.meilisearch.com/references/settings.html
+        https://docs.meilisearch.com/reference/api/settings.html
 
         Returns
         -------
@@ -495,30 +442,26 @@ class Index():
             An error containing details about why MeiliSearch can't process your request. MeiliSearch error codes are described here: https://docs.meilisearch.com/errors/#meilisearch-errors
         """
         return self.http.get(
-            '{}/{}/{}'.format(
-                self.config.paths.index,
-                self.uid,
-                self.config.paths.setting
-            )
+            f'{self.config.paths.index}/{self.uid}/{self.config.paths.setting}'
         )
 
     def update_settings(self, body):
         """Update settings of the index.
 
-        https://docs.meilisearch.com/references/settings.html#update-settings
+        https://docs.meilisearch.com/reference/api/settings.html#update-settings
 
         Parameters
         ----------
         body: dict
             Dictionary containing the settings of the index.
             More information:
-            https://docs.meilisearch.com/references/settings.html#update-settings
+            https://docs.meilisearch.com/reference/api/settings.html#update-settings
 
         Returns
         -------
         update: dict
             Dictionary containing an update id to track the action:
-            https://docs.meilisearch.com/references/updates.html#get-an-update-status
+            https://docs.meilisearch.com/reference/api/updates.html#get-an-update-status
 
         Raises
         ------
@@ -526,24 +469,20 @@ class Index():
             An error containing details about why MeiliSearch can't process your request. MeiliSearch error codes are described here: https://docs.meilisearch.com/errors/#meilisearch-errors
         """
         return self.http.post(
-            '{}/{}/{}'.format(
-                self.config.paths.index,
-                self.uid,
-                self.config.paths.setting
-            ),
+            f'{self.config.paths.index}/{self.uid}/{self.config.paths.setting}',
             body
         )
 
     def reset_settings(self):
         """Reset settings of the index to default values.
 
-        https://docs.meilisearch.com/references/settings.html#reset-settings
+        https://docs.meilisearch.com/reference/api/settings.html#reset-settings
 
         Returns
         -------
         update: dict
             Dictionary containing an update id to track the action:
-            https://docs.meilisearch.com/references/updates.html#get-an-update-status
+            https://docs.meilisearch.com/reference/api/updates.html#get-an-update-status
 
         Raises
         ------
@@ -551,11 +490,7 @@ class Index():
             An error containing details about why MeiliSearch can't process your request. MeiliSearch error codes are described here: https://docs.meilisearch.com/errors/#meilisearch-errors
         """
         return self.http.delete(
-            '{}/{}/{}'.format(
-                self.config.paths.index,
-                self.uid,
-                self.config.paths.setting
-            ),
+            f'{self.config.paths.index}/{self.uid}/{self.config.paths.setting}'
         )
 
     # RANKING RULES SUB-ROUTES
@@ -591,7 +526,7 @@ class Index():
         -------
         update: dict
             Dictionary containing an update id to track the action:
-            https://docs.meilisearch.com/references/updates.html#get-an-update-status
+            https://docs.meilisearch.com/reference/api/updates.html#get-an-update-status
 
         Raises
         ------
@@ -610,7 +545,7 @@ class Index():
         -------
         update: dict
             Dictionary containing an update id to track the action:
-            https://docs.meilisearch.com/references/updates.html#get-an-update-status
+            https://docs.meilisearch.com/reference/api/updates.html#get-an-update-status
 
         Raises
         ------
@@ -630,8 +565,8 @@ class Index():
 
         Returns
         -------
-        settings: str
-            String containing the distinct attribute of the index.
+        settings: str | None
+            String containing the distinct attribute of the index. If no distinct attribute None is returned.
 
         Raises
         ------
@@ -655,7 +590,7 @@ class Index():
         -------
         update: dict
             Dictionary containing an update id to track the action:
-            https://docs.meilisearch.com/references/updates.html#get-an-update-status
+            https://docs.meilisearch.com/reference/api/updates.html#get-an-update-status
 
         Raises
         ------
@@ -674,7 +609,7 @@ class Index():
         -------
         update: dict
             Dictionary containing an update id to track the action:
-            https://docs.meilisearch.com/references/updates.html#get-an-update-status
+            https://docs.meilisearch.com/reference/api/updates.html#get-an-update-status
 
         Raises
         ------
@@ -718,7 +653,7 @@ class Index():
         -------
         update: dict
             Dictionary containing an update id to track the action:
-            https://docs.meilisearch.com/references/updates.html#get-an-update-status
+            https://docs.meilisearch.com/reference/api/updates.html#get-an-update-status
 
         Raises
         ------
@@ -737,7 +672,7 @@ class Index():
         -------
         update: dict
             Dictionary containing an update id to track the action:
-            https://docs.meilisearch.com/references/updates.html#get-an-update-status
+            https://docs.meilisearch.com/reference/api/updates.html#get-an-update-status
 
         Raises
         ------
@@ -781,7 +716,7 @@ class Index():
         -------
         update: dict
             Dictionary containing an update id to track the action:
-            https://docs.meilisearch.com/references/updates.html#get-an-update-status
+            https://docs.meilisearch.com/reference/api/updates.html#get-an-update-status
 
         Raises
         ------
@@ -800,7 +735,7 @@ class Index():
         -------
         update: dict
             Dictionary containing an update id to track the action:
-            https://docs.meilisearch.com/references/updates.html#get-an-update-status
+            https://docs.meilisearch.com/reference/api/updates.html#get-an-update-status
 
         Raises
         ------
@@ -844,7 +779,7 @@ class Index():
         -------
         update: dict
             Dictionary containing an update id to track the action:
-            https://docs.meilisearch.com/references/updates.html#get-an-update-status
+            https://docs.meilisearch.com/reference/api/updates.html#get-an-update-status
 
         Raises
         ------
@@ -863,7 +798,7 @@ class Index():
         -------
         update: dict
             Dictionary containing an update id to track the action:
-            https://docs.meilisearch.com/references/updates.html#get-an-update-status
+            https://docs.meilisearch.com/reference/api/updates.html#get-an-update-status
 
         Raises
         ------
@@ -907,7 +842,7 @@ class Index():
         -------
         update: dict
             Dictionary containing an update id to track the action:
-            https://docs.meilisearch.com/references/updates.html#get-an-update-status
+            https://docs.meilisearch.com/reference/api/updates.html#get-an-update-status
 
         Raises
         ------
@@ -926,7 +861,7 @@ class Index():
         -------
         update: dict
             Dictionary containing an update id to track the action:
-            https://docs.meilisearch.com/references/updates.html#get-an-update-status
+            https://docs.meilisearch.com/reference/api/updates.html#get-an-update-status
 
         Raises
         ------
@@ -970,7 +905,7 @@ class Index():
         -------
         update: dict
             Dictionary containing an update id to track the action:
-            https://docs.meilisearch.com/references/updates.html#get-an-update-status
+            https://docs.meilisearch.com/reference/api/updates.html#get-an-update-status
 
         Raises
         ------
@@ -989,7 +924,7 @@ class Index():
         -------
         update: dict
             Dictionary containing an update id to track the action:
-            https://docs.meilisearch.com/references/updates.html#get-an-update-status
+            https://docs.meilisearch.com/reference/api/updates.html#get-an-update-status
 
         Raises
         ------
@@ -1001,9 +936,4 @@ class Index():
         )
 
     def __settings_url_for(self, sub_route):
-        return '{}/{}/{}/{}'.format(
-            self.config.paths.index,
-            self.uid,
-            self.config.paths.setting,
-            sub_route
-        )
+        return f'{self.config.paths.index}/{self.uid}/{self.config.paths.setting}/{sub_route}'
